@@ -7,7 +7,7 @@ import click
 from lxml import etree
 
 from perfectextractor.apps.extractor.base import BaseExtractor
-from perfectextractor.apps.extractor.models import Alignment
+from perfectextractor.apps.extractor.models import Alignment, MARKUP
 from perfectextractor.apps.extractor.perfectextractor import PerfectExtractor, PRESENT
 from perfectextractor.apps.extractor.posextractor import PoSExtractor
 from perfectextractor.apps.extractor.recentpastextractor import RecentPastExtractor
@@ -94,12 +94,15 @@ class EuroparlExtractor(BaseEuroparl, BaseExtractor):
             results.append(result)
         return results
 
-    def get_sentence_words(self, sentence):
+    def get_sentence_words(self, sentence, match=None):
         # TODO: this is copied from apps/models.py. Consider refactoring!
         s = []
         # TODO: this xPath-expression might be specific for a corpus
         for w in sentence.xpath('.//w'):
-            s.append(w.text.strip() if w.text else ' ')
+            if match is not None and w.get('id') == match.get('id'):
+                s.append(MARKUP.format(w.text.strip()))
+            else:
+                s.append(w.text.strip() if w.text else ' ')
         return ' '.join(s)
 
     def get_line_by_number(self, tree, segment_number):
@@ -280,22 +283,31 @@ class EuroparlPoSExtractor(EuroparlExtractor, PoSExtractor):
         # Find potential words matching the part-of-speech
         pos_attr = self.config.get(self.l_from, 'pos')
         lemma_attr = self.config.get('all', 'lemma_attr')
-        xp = './/w[contains(" {value} ", concat(" ", @{element}, " "))]'
         ns = {}
+        predicate = 'contains(" {value} ", concat(" ", @{element}, " "))'
+        predicates = []
+
+        if self.lemmata_list:
+            predicates.append(predicate.format(element=lemma_attr, value=' '.join(self.lemmata_list)))
+
+        if self.tokens:
+            predicates.append(predicate.format(element='id', value=' '.join(self.tokens.keys())))
+
         if self.pos:
-            xpath = xp.format(element=pos_attr, value=' '.join(self.pos))
-        elif self.tokens:
-            xpath = xp.format(element='id', value=' '.join(self.tokens.keys()))
-        elif self.regex:
+            predicates.append(predicate.format(element=pos_attr, value=' '.join(self.pos)))
+
+        if self.regex:
             # prepare a pattern that combines multiple regexps using OR operators
             # and non-capturing groups
             pattern = '|'.join('(?:{})'.format(r) for r in self.regex)
 
             # special namespace required for enabling regular expresssion functions
             ns = {"re": "http://exslt.org/regular-expressions"}
-            xpath = './/w[re:test(., "{pattern}", "i")]'.format(pattern=pattern)
-        else:
-            xpath = xp.format(element=lemma_attr, value=' '.join(self.lemmata_list))
+            predicates.append('re:test(., "{pattern}", "i")'.format(pattern=pattern))
+
+        xpath = './/w'
+        if predicates:
+            xpath = './/w[{}]'.format(' and '.join(predicates))
 
         for _, s in s_trees:
             if self.sentence_ids and s.get('id') not in self.sentence_ids:
@@ -316,7 +328,7 @@ class EuroparlPoSExtractor(EuroparlExtractor, PoSExtractor):
                 if self.output == XML:
                     result.append('<root>' + etree.tostring(s, encoding=str) + '</root>')
                 else:
-                    result.append(self.get_sentence_words(s))
+                    result.append(self.get_sentence_words(s, w))
                 self.append_metadata(w, s, result)
 
                 # Find the translated lines
@@ -559,7 +571,7 @@ class EuroparlPerfectExtractor(EuroparlExtractor, PerfectExtractor):
 
             if self.search_in_to:
                 for e in s.xpath(self.config.get(language_to, 'xpath')):
-                    pp = self.check_present_perfect(e, language_to)
+                    pp = self.check_perfect(e, language_to)
                     if pp:
                         sentence = pp.mark_sentence()
                         break
@@ -583,7 +595,11 @@ class EuroparlPerfectExtractor(EuroparlExtractor, PerfectExtractor):
             aux_xpath = l_config.get(xpath, l_config.get(xpath_fallback))
 
             for e in s.xpath(aux_xpath):
-                pp = self.check_present_perfect(e, self.l_from)
+                pp = self.check_perfect(e, self.l_from)
+
+                # apply position filter
+                if self.position and not e.get('id').endswith('.' + str(self.position)):
+                    continue
 
                 # If this is really a present/past perfect, add it to the result
                 if pp:
